@@ -1,4 +1,4 @@
-from .generated.api import trading_pb2_grpc as trading_grpc
+from .generated.data_node.api.v1 import trading_data_grpc
 from .grpcclient import GRPCClient
 
 
@@ -9,7 +9,9 @@ class VegaTradingDataClient(GRPCClient):
 
     def __init__(self, url: str, channel=None) -> None:
         super().__init__(url, channel=channel)
-        self._trading_data = trading_grpc.TradingDataServiceStub(self.channel)
+        self._tradingdata = trading_data_grpc.TradingDataServiceStub(
+            self.channel
+        )
 
     def __getattr__(self, funcname):
-        return getattr(self._trading_data, funcname)
+        return getattr(self._tradingdata, funcname)
